netapp_ontap.models.fpolicy_events API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fpolicy_events`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FpolicyEventsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FpolicyEvents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `file_operations: FpolicyEventFileOperations GET POST PATCH`

    Specifies the file operations for the FPolicy event. You must specify a valid protocol in the protocol parameter. The event will check the operations specified from all client requests using the protocol.

  `filters: FpolicyEventFilters GET POST PATCH`

    Specifies the list of filters for a given file operation for the specified protocol. When you specify the filters, you must specify the valid protocols and a valid file operations.

  `monitor_fileop_failure: bool GET POST PATCH`

    Specifies whether failed file operations monitoring is required.

  `name: str GET POST`

    Specifies the name of the FPolicy event.

    Example: event_cifs

  `protocol: str GET POST PATCH`

    Protocol for which event is created. If you specify protocol, then you must also specify a valid value for the file operation parameters. The value of this parameter must be one of the following:

        * cifs  - for the CIFS protocol.
        * nfsv3 - for the NFSv3 protocol.
        * nfsv4 - for the NFSv4 protocol.

    Valid choices:

    - cifs
    - nfsv3
    - nfsv4
  `volume_monitoring: bool GET POST PATCH`

    Specifies whether volume operation monitoring is required.